@@ -23,6 +23,7 @@
 #include <std.h>
 #include <limits.h>
 #include <new.h>
+#include "renew.h"
 #include "options.h"
 #include "trie.h"
 
@@ -130,7 +131,7 @@ Trie::cmp (char **s1, char **s2)
 void 
 Trie::sort (void)
 {
-  typedef int (*PTF)(void *, void *);
+  typedef int (*PTF)(const void *, const void *);
   qsort ((void *) keys, current_size, sizeof *keys, PTF (cmp));
 }
 
