@@ -8,8 +8,9 @@ TSRCS =  tObstack.cc tString.cc tInteger.cc tRational.cc \
  tiLList.cc
 EOF
 
-TESTS0="tObstack tString tInteger tRational tComplex tBitSet tBitString tRandom"
-TESTS1="tStack tQueue tDeque tPQ tSet tBag tMap tFix tFix16 tFix24 tList tPlex tLList tVec"
+TESTS0="tObstack tString tInteger tRational tComplex tBitSet"\
+" tBitString tFix tFix16 tFix24 tRandom"
+TESTS1="tStack tQueue tDeque tPQ tSet tBag tMap tList tPlex tLList tVec"
 
 cat <<EOF
 # executables
@@ -133,16 +134,15 @@ LIB_FOR_tFix16=-lm
 LIB_FOR_tFix24=-lm
 LIB_FOR_tCurses="-lcurses -ltermcap"
 
-for TEST in $TESTS0 tiLList; do
+for TEST in $TESTS0 tiLList tCurses tGetOpt; do
   echo "${TEST}: ${TEST}.o"
   echo '	$(CXX) $(LDFLAGS)' "${TEST}.o" '-o $@ $(LIBS)' \
 	`eval echo '$LIB_FOR_'$TEST`
   echo ""
 done
-for TEST in twrapper tgwrapper $TESTS1 tCurses tGetOpt; do
+for TEST in twrapper tgwrapper $TESTS1; do
   echo "${TEST}: " '$(LIBTEST)' " ${TEST}.o"
-  echo '	$(CXX) $(LDFLAGS)' "${TEST}.o" '-o $@ $(LIBTEST) $(LIBS)' \
-	`eval echo '$LIB_FOR_'$TEST`
+  echo '	$(CXX) $(LDFLAGS)' "${TEST}.o" '-o $@ $(LIBTEST) $(LIBS)'
   echo ""
 done
 
