@@ -243,4 +243,9 @@ main()
   cout << "\nEnd of test\n";
   return 0;
 }
+
+template class SLNode<int>;
+template class SLList<int>;
+template class DLNode<int>;
+template class DLList<int>;
 #endif
