@@ -25,7 +25,7 @@ the executable file might be covered by the GNU General Public License. */
 #ifdef __GNUC__
 #pragma implementation
 #endif
-
+#define _STREAM_COMPAT
 #include "builtinbuf.h"
 #include "iostreamP.h"
 
@@ -81,16 +81,16 @@ int builtinbuf::sys_stat(void* buf) // Actually, a (struct stat*)
 int builtinbuf::sys_close()
 { return _jumps->__close(this); }
 
-static const void *get_builtin_vtable()
+#ifdef _STREAM_COMPAT
+/* These methods are TEMPORARY, for binary compatibility! */
+#include <stdlib.h>
+void ios::_IO_fix_vtable() const
 {
-  char _dummy[sizeof(builtinbuf)];
-  ((builtinbuf*)_dummy)->builtinbuf::builtinbuf();
-  return ((builtinbuf*)_dummy)->_vtable();
+  abort ();
 }
 
-const void *builtinbuf::vtable = get_builtin_vtable();
-
 void ios::_IO_fix_vtable()
 {
-  _strbuf->_vtable() = builtinbuf::vtable;
+  ((const ios*) this)->_IO_fix_vtable();
 }
+#endif
