@@ -41,7 +41,7 @@ _IO_scanf
   int ret;
   va_list args;
   _IO_va_start(args, format);
-  ret = _IO_vfscanf(_IO_stdin, format, args);
+  ret = _IO_vfscanf(_IO_stdin, format, args, NULL);
   va_end(args);
   return ret;
 }
