@@ -17,6 +17,11 @@ You should have received a copy of the GNU Library General Public
 License along with this library; if not, write to the Free
 Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */
+
+/*
+ *	ANSI Standard: 4.9 INPUT/OUTPUT <stdio.h>
+ */
+
 #ifndef _STDIO_H
 #define _STDIO_H
 #define _STDIO_USES_IOSTREAM
@@ -82,11 +87,6 @@ extern FILE *stdin, *stdout, *stderr; /* TODO */
 #define stdout _IO_stdout
 #define stderr _IO_stderr
 
-#define getc(fp) _IO_getc(fp)
-#define putc(c, fp) _IO_putc(c, fp)
-#define putchar(c) putc(c, stdout)
-#define getchar() getc(stdin)
-
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -118,9 +118,13 @@ extern int fseek __P((FILE* fp, long int offset, int whence));
 extern int fsetpos __P((FILE* fp, const fpos_t *pos));
 extern long int ftell __P((FILE* fp));
 extern size_t fwrite __P((const void*, size_t, size_t, FILE*));
+extern int getc __P((FILE *));
+extern int getchar __P((void));
 extern char* gets __P((char*));
 extern void perror __P((const char *));
 extern int printf __P((const char* format, ...));
+extern int putc __P((int, FILE *));
+extern int putchar __P((int));
 extern int puts __P((const char *str));
 extern int remove __P((const char*));
 extern int rename __P((const char* _old, const char* _new));
@@ -139,6 +143,12 @@ extern int vfprintf __P((FILE *fp, char const *fmt0, _G_va_list));
 extern int vprintf __P((char const *fmt, _G_va_list));
 extern int vsprintf __P((char* string, const char* format, _G_va_list));
 
+#ifndef __STRICT_ANSI__
+extern int vfscanf __P((FILE*, const char *, _G_va_list));
+extern int vscanf __P((const char *, _G_va_list));
+extern int vsscanf __P((const char *, const char *, _G_va_list));
+#endif
+
 #if !defined(__STRICT_ANSI__) || defined(_POSIX_SOURCE)
 extern FILE *fdopen __P((int, const char *));
 extern int fileno __P((FILE*));
@@ -146,9 +156,22 @@ extern FILE* popen __P((const char*, const char*));
 extern int pclose __P((FILE*));
 #endif
 
+#ifdef __USE_GNU
+extern _IO_ssize_t getdelim __P ((char **, size_t *, int, FILE*));
+extern _IO_ssize_t getline __P ((char **, size_t *, FILE *));
+
+extern int snprintf __P ((char *, size_t, const char *, ...));
+extern int vsnprintf __P ((char *, size_t, const char *, _G_va_list));
+#endif
+
 extern int __underflow __P((struct _IO_FILE*));
 extern int __overflow __P((struct _IO_FILE*, int));
 
+#define getc(fp) _IO_getc(fp)
+#define putc(c, fp) _IO_putc(c, fp)
+#define putchar(c) putc(c, stdout)
+#define getchar() getc(stdin)
+
 #ifdef __cplusplus
 }
 #endif
