@@ -23,11 +23,12 @@ This exception does not however invalidate any other reasons why
 the executable file might be covered by the GNU General Public License. */
 
 #include "libioP.h"
+#include "stdio.h"
 
 int
 vscanf(format, args)
      const char *format;
      _IO_va_list args;
 {
-  return _IO_vfscanf(_IO_stdin, format, args);
+  return _IO_vfscanf(_IO_stdin, format, args, NULL);
 }
